Module unc_client_primitives::types
source · Structs
- Actor message requesting block provider by EpochId and BlockHeight.
- Actor message requesting block by id, hash or sync state.
- Get block with the block merkle tree. Used for testing
- Actor message requesting block provider by EpochId and BlockHeight.
- Queries client for given path / data.
- Stores status of shard sync and statuses of downloading shards.
- Status of given transaction including all the subsequent receipts.
Enums
- Combines errors coming from chain, tx pool and block producer.
- Actor message requesting a chunk by chunk hash and block hash + shard id.
- Various status of syncing a specific shard.
- Various status sync can be in, whether it’s fast sync or archival.
Functions
- Formats the given ShardSyncDownload for logging.